# Beendet

Das Experiment wurde erfolgreich abgeschlossen.

- Zeit: `%(time)s`
- Protokolldatei: `%(logfile)s`

Du kannst:

[Protokolldatei öffnen](opensesame://event.after_experiment_open_logfile){: .important-button}<br />
[Protokolldatei-Ordner öffnen](opensesame://event.after_experiment_open_logfile_folder){: .button}<br />
[Protokolldatei in Dateisammlung kopieren](opensesame://event.after_experiment_copy_logfile){: .button}
